netapp_ontap.resources.cifs_symlink_mapping API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.cifs_symlink_mapping`

Copyright © 2020 NetApp Inc. All rights reserved.

## Overview

ONTAP allows both CIFS and NFS to access the same datastore. This datastore can contain symbolic links which are files, created by UNIX clients. It contains a reference to another file or directory. If an SMB client accesses a symbolic link, it is redirected to the target file or directory that the symbolic link refers to. The symbolic links can point to files within the volume that contain the share, or to files that are contained in other volumes on the Storage Virtual Machine (SVM), or even to volumes contained on other SVMs.

There are two types of symbolic links:

- Relative A relative symbolic link contains a reference to the file or directory relative to its parent directory. Therefore, the path of the file it is referring to should not begin with a backslash (/). If you enable symbolic links on a share, relative symbolic links work without UNIX symlink mapping.
- Absolute An absolute symbolic link contains a reference to a file or directory in the form of an absolute path. Therefore, the path of the file it is referring to should begin with a backslash (/). An absolute symbolic link can refer to a file or directory within or outside of the file system of the symbolic link. If the target is not in the same local file system, the symbolic link is called a "widelink". If the symbolic link is enabled on a share and absolute symbolic links do not work right away, the mapping between the UNIX path of the symbolic link to the destination CIFS path must be created. When creating absolute symbolic link mappings, locality could be either "local" or "widelink" and it must be specified. If UNIX symlink mapping is created for a file or directory which is outside of the local share but the locality is set to "local", ONTAP does not allow access to the target. A UNIX symbolic link support could be added to SMB shares by specifying the unix_symlink property during the creation of SMB shares or at any time by modifying the existing SMB unix_symlink property. UNIX symbolic link support is enabled by default.

## Examples

### Creating a UNIX symlink mapping for CIFS shares

To create UNIX symlink mappings for SMB shares, use the following API. Note the return_records=true query parameter used to obtain the newly created entry in the response.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import CifsSymlinkMapping

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = CifsSymlinkMapping()
        resource.svm.name = "vs1"
        resource.svm.uuid = "000c5cd2-ebdf-11e8-a96e-0050568ea3cb"
        resource.target.home_directory = False
        resource.target.locality = "local"
        resource.target.path = "/dir1/dir2/"
        resource.target.server = "cifs123"
        resource.target.share = "sh1"
        resource.unix_path = "/mnt/eng_volume/"
        resource.post(hydrate=True)
        print(resource)

Try it out

    CifsSymlinkMapping(
        {
            "unix_path": "/mnt/eng_volume/",
            "svm": {"name": "vs1", "uuid": "000c5cd2-ebdf-11e8-a96e-0050568ea3cb"},
            "target": {
                "locality": "local",
                "path": "/dir1/dir2/",
                "server": "cifs123",
                "home_directory": False,
                "share": "sh1",
            },
        }
    )

### Retrieving UNIX symlink mappings for all SVMs in the cluster

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import CifsSymlinkMapping

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(list(CifsSymlinkMapping.get_collection(fields="*", return_timeout=15)))

Try it out

    [
        CifsSymlinkMapping(
            {
                "unix_path": "/mnt/eng_volume/",
                "_links": {
                    "self": {
                        "href": "/api/protocols/cifs/unix-symlink-mapping/000c5cd2-ebdf-11e8-a96e-0050568ea3cb/%2Fmnt%2Feng_volume%2F"
                    }
                },
                "svm": {
                    "name": "vs1",
                    "uuid": "000c5cd2-ebdf-11e8-a96e-0050568ea3cb",
                    "_links": {
                        "self": {
                            "href": "/api/svm/svms/000c5cd2-ebdf-11e8-a96e-0050568ea3cb"
                        }
                    },
                },
                "target": {
                    "locality": "local",
                    "path": "/dir1/dir2/",
                    "server": "CIFS123",
                    "home_directory": False,
                    "share": "sh1",
                },
            }
        ),
        CifsSymlinkMapping(
            {
                "unix_path": "/mnt/eng_volume/",
                "_links": {
                    "self": {
                        "href": "/api/protocols/cifs/unix-symlink-mapping/1d30d1b1-ebdf-11e8-a96e-0050568ea3cb/%2Fmnt%2Feng_volume%2F"
                    }
                },
                "svm": {
                    "name": "vs2",
                    "uuid": "1d30d1b1-ebdf-11e8-a96e-0050568ea3cb",
                    "_links": {
                        "self": {
                            "href": "/api/svm/svms/1d30d1b1-ebdf-11e8-a96e-0050568ea3cb"
                        }
                    },
                },
                "target": {
                    "locality": "widelink",
                    "path": "/dir1/dir2/",
                    "server": "ENGCIFS",
                    "home_directory": False,
                    "share": "ENG_SHARE",
                },
            }
        ),
    ]

### Retrieving a specific UNIX symlink mapping for an SVM

The mapping being returned is identified by the UUID of its SVM and the unix-path.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import CifsSymlinkMapping

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = CifsSymlinkMapping(
            unix_path="/mnt/eng_volume/",
            **{"svm.uuid": "000c5cd2-ebdf-11e8-a96e-0050568ea3cb"}
        )
        resource.get()
        print(resource)

Try it out

    CifsSymlinkMapping(
        {
            "unix_path": "/mnt/eng_volume/",
            "svm": {"name": "vs1", "uuid": "000c5cd2-ebdf-11e8-a96e-0050568ea3cb"},
            "target": {
                "locality": "local",
                "path": "/dir1/dir2/",
                "server": "CIFS123",
                "home_directory": False,
                "share": "sh1",
            },
        }
    )

### Updating a specific UNIX symlink mapping for an SVM

The mapping being modified is identified by the UUID of its SVM and the unix-path.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import CifsSymlinkMapping

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = CifsSymlinkMapping(
            unix_path="/mnt/eng_volume/",
            **{"svm.uuid": "000c5cd2-ebdf-11e8-a96e-0050568ea3cb"}
        )
        resource.target.home_directory = True
        resource.target.locality = "widelink"
        resource.target.path = "/new_path/"
        resource.target.server = "HR_SERVER"
        resource.target.share = "sh2"
        resource.patch()

### Removing a specific UNIX symlink mapping for an SVM

The mapping being removed is identified by the UUID of its SVM and the unix-path.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import CifsSymlinkMapping

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = CifsSymlinkMapping(
            unix_path="/mnt/eng_volume/",
            **{"svm.uuid": "000c5cd2-ebdf-11e8-a96e-0050568ea3cb"}
        )
        resource.delete()

## Classes

`class CifsSymlinkMapping (*args, **kwargs)`

  ONTAP allows for both CIFS and NFS access to the same datastore. This datastore can contain symbolic links created by UNIX clients which can point anywhere from the perspective of the UNIX client. To Access such UNIX symlink from CIFS share, we need to create a CIFS symbolic link path mapping from a UNIX symlink and target it as a CIFS path.

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection(*args, connection: HostConnection = None, **kwargs) -> int`

    Retrieves UNIX symbolic link mappings for CIFS clients.

    ### Related ONTAP commands

    - `vserver cifs symlink show`

    ### Learn more

    - `DOC /protocols/cifs/unix-symlink-mapping`

    Fetch a count of all objects of this type from the host.

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def delete_collection(*args, body: typing.Union = None, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Deletes the UNIX symbolic link mapping for CIFS clients.

    ### Related ONTAP commands

    - `vserver cifs symlink delete`

    ### Learn more

    - `DOC /protocols/cifs/unix-symlink-mapping`

    Delete all objects in a collection which match the given query.

    All records on the host which match the query will be deleted.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to delete the collection of bars for a particular foo, the foo.name value should be passed.
    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def find(*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves UNIX symbolic link mappings for CIFS clients.

    ### Related ONTAP commands

    - `vserver cifs symlink show`

    ### Learn more

    - `DOC /protocols/cifs/unix-symlink-mapping`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection(*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> typing.Iterable`

    Retrieves UNIX symbolic link mappings for CIFS clients.

    ### Related ONTAP commands

    - `vserver cifs symlink show`

    ### Learn more

    - `DOC /protocols/cifs/unix-symlink-mapping`

    Fetch a list of all objects of this type from the host.

    This is a lazy fetch, making API calls only as necessary when the result of this call is iterated over. For instance, if max_records is set to 5, then iterating over the collection causes an API call to be sent to the server once for every 5 records. If the client stops iterating before getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def patch_collection(body: dict, *args, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Updates the UNIX symbolic link mapping for CIFS clients.

    ### Related ONTAP commands

    - `vserver cifs symlink modify`

    ### Learn more

    - `DOC /protocols/cifs/unix-symlink-mapping`

    Patch all objects in a collection which match the given query.

    All records on the host which match the query will be patched with the provided body.

    ## Args

    `body`
      A dictionary of name/value pairs to set on all matching members of the collection.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to patch the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Methods

  `def delete(self, body: typing.Union = None, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Deletes the UNIX symbolic link mapping for CIFS clients.

    ### Related ONTAP commands

    - `vserver cifs symlink delete`

    ### Learn more

    - `DOC /protocols/cifs/unix-symlink-mapping`

    Send a deletion request to the host for this object.

    ## Args

    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def get(self, **kwargs) -> NetAppResponse`

    Retrieves a UNIX symbolic link mapping for CIFS clients.

    ### Related ONTAP commands

    - `vserver cifs symlink show`

    ### Learn more

    - `DOC /protocols/cifs/unix-symlink-mapping`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def patch(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Updates the UNIX symbolic link mapping for CIFS clients.

    ### Related ONTAP commands

    - `vserver cifs symlink modify`

    ### Learn more

    - `DOC /protocols/cifs/unix-symlink-mapping`

    Send the difference in the object's state to the host as a modification request.

    Calculates the difference in the object's state since the last time we interacted with the host and sends this in the request body.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Creates a UNIX symbolic link mapping for a CIFS client.

    ### Required properties

    - `svm.uuid` or `svm.name` - Existing SVM in which to create the CIFS unix-symlink-mapping.
    - `unix_path` - UNIX path to which the CIFS symlink mapping to be created.
    - `target.share` - CIFS share name on the destination CIFS server to which the UNIX symbolic link is pointing.
    - `target.path` - CIFS path on the destination to which the symbolic link maps.

    ### Default property values

    - `target.server` - Local_NetBIOS_Server_Name
    - `locality` - local
    - `home_directory` - false

    ### Related ONTAP commands

    - `vserver cifs symlink create`

    ### Learn more

    - `DOC /protocols/cifs/unix-symlink-mapping`

    Send this object to the host as a creation request.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
`class CifsSymlinkMappingSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the CifsSymlinkMapping object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `links GET`

    The links field of the cifs_symlink_mapping.

  `svm GET POST PATCH`

    The svm field of the cifs_symlink_mapping.

  `target GET POST PATCH`

    The target field of the cifs_symlink_mapping.

  `unix_path GET POST`

    Specifies the UNIX path prefix to be matched for the mapping.

    Example: /mnt/eng_volume/